/*  -- translated by f2c (version 20100827).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int uswapz_(real *x1, real *x2, integer *n)
{
    /* System generated locals */
    integer i__1;

    /* Local variables */
    static integer i__;
    static real xtmp;

    /* Parameter adjustments */
    --x2;
    --x1;

    /* Function Body */
    i__1 = *n;
    for (i__ = 1; i__ <= i__1; ++i__) {
	xtmp = x1[i__];
	x1[i__] = x2[i__];
	x2[i__] = xtmp;
/* L10: */
    }
    return 0;
} /* uswapz_ */

